@@ -261,13 +261,14 @@ class Update(object):
         self.addProgress()
         if clean_on_error:
             try:
+                layman = Layman(dv.Get('cl_update_layman_installed'),
+                                dv.Get('cl_update_layman_make'),
+                                dv.Get('cl_update_layman_conf'))
+                if repname != "portage":
+                    layman.add(repname, url, rpath)
                 if not self._syncRepository(repname, url, rpath, revision, branch,
                                      cb_progress=self.setProgress):
                     return "skip"
-                layman = Layman(dv.Get('cl_update_layman_installed'),
-                                dv.Get('cl_update_layman_make'))
-                if repname != "portage":
-                    layman.add(repname, url, rpath)
                 return True
             except GitError as e:
                 if e.addon:
@@ -295,7 +296,8 @@ class Update(object):
                 return "skip"
 
         layman = Layman(dv.Get('cl_update_layman_installed'),
-                        dv.Get('cl_update_layman_make'))
+                        dv.Get('cl_update_layman_make'),
+                        dv.Get('cl_update_layman_conf'))
         if repname != "portage":
             layman.add(repname, url, rpath)
         return True
